@@ -11,3 +11,11 @@ class ImproperConfigurationError(SemanticReleaseBaseError):
 
 class UnknownCommitMessageStyleError(SemanticReleaseBaseError):
     pass
+
+
+class GitError(SemanticReleaseBaseError):
+    pass
+
+
+class CiVerificationError(SemanticReleaseBaseError):
+    pass
